@@ -1,4 +1,4 @@
-from src.myutil import *
+import advcalc
 
 def test_sum():
     assert sum((8, 2, 3, 0, 7)) == 20
